﻿// Accord Statistics Library
// The Accord.NET Framework
// http://accord-framework.net
//
// Copyright © César Souza, 2009-2014
// cesarsouza at gmail.com
//
//    This library is free software; you can redistribute it and/or
//    modify it under the terms of the GNU Lesser General Public
//    License as published by the Free Software Foundation; either
//    version 2.1 of the License, or (at your option) any later version.
//
//    This library is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//    Lesser General Public License for more details.
//
//    You should have received a copy of the GNU Lesser General Public
//    License along with this library; if not, write to the Free Software
//    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

namespace Accord.Statistics
{
    using System.Runtime.CompilerServices;
    using Accord.Statistics.Models;
    using Accord.Statistics.Models.Markov;
    using Accord.Statistics.Models.Markov.Hybrid;

    /// <summary>
    ///  Statistics, including probability distributions, regression 
    ///  models and hypothesis testing.
    /// </summary>
    /// 
    /// <remarks>
    /// <para>
    ///   One of the most prominent features on this namespace is the great number
    ///   of <see cref="Accord.Statistics.Distributions">probability distributions
    ///   </see>, <see cref="Accord.Statistics.Kernels">kernel functions</see>, and
    ///   <see cref="Accord.Statistics.Testing">hypothesis tests</see> available
    ///   to build your statistics processing applications. A great number of <see
    ///   cref="Accord.Statistics.Analysis">statistical analysis</see>, including
    ///   classical and <c>kernel</c>-based ones are also available to help analyze, 
    ///   process and simplify your data.</para>
    ///   
    /// <para>
    ///   This namespace is also home for the one of the most used features of the
    ///   framework, the <see cref="Accord.Statistics.Models.Markov">Hidden Markov models
    ///   </see> and <see cref="Accord.Statistics.Models.Fields">Conditional Random Fields
    ///   </see>. Such models can be used to build <see cref="HiddenMarkovClassifier">
    ///   sequence classifiers</see>, perform gesture recognition, and can even be
    ///   combined with neural networks to create <see cref="HybridMarkovClassifier">
    ///   hybrid models</see> uniting those two technologies. Other models include
    ///   <see cref="Accord.Statistics.Models.Regression">regression and survival
    ///   models</see>.</para>
    ///   
    ///   
    /// <para>
    ///   The namespace class diagram is shown below. </para>
    ///   <img src="..\diagrams\classes\Accord.Statistics.png" />
    ///   
    /// <para>
    ///   Please note that class diagrams for each of the inner namespaces are 
    ///   also available within their own documentation pages.</para>
    /// </remarks>
    /// 
    /// <seealso cref="Accord.Statistics.Analysis"/>
    /// <seealso cref="Accord.Statistics.Distributions"/>
    /// <seealso cref="Accord.Statistics.Filters"/>
    /// <seealso cref="Accord.Statistics.Formats"/>
    /// <seealso cref="Accord.Statistics.Kernels"/>
    /// <seealso cref="Accord.Statistics.Links"/>
    /// <seealso cref="Accord.Statistics.Models"/>
    /// <seealso cref="Accord.Statistics.Moving"/>
    /// <seealso cref="Accord.Statistics.Running"/>
    /// <seealso cref="Accord.Statistics.Testing"/>
    /// <seealso cref="Accord.Statistics.Visualizations"/>
    /// 
    [CompilerGenerated]
    class NamespaceDoc
    {
    }
}
